@@ -1,6 +1,9 @@
-# Django settings for lfs development buildout.
-
+# python imports
 import os
+
+# django imports
+from django.utils.translation import gettext_lazy as _
+
 DIRNAME = os.path.dirname(__file__)
 
 DEBUG = True
@@ -64,6 +67,12 @@ ADMIN_MEDIA_PREFIX = '/static/admin/'
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = '+0zsw5n@v7*rhl6r6ufqhoc6jlqq0f-u8c+gh(hjb+_jmg@rh6'
 
+STATICFILES_FINDERS = (
+    'django.contrib.staticfiles.finders.FileSystemFinder',
+    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
+    'compressor.finders.CompressorFinder',
+)
+
 # List of callables that know how to import templates from various sources.
 TEMPLATE_LOADERS = (
     'django.template.loaders.filesystem.load_template_source',
@@ -90,6 +99,7 @@ TEMPLATE_DIRS = (
 
 INSTALLED_APPS = (
     "lfstheme",
+    "compressor",
     "django.contrib.admin",
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -99,7 +109,6 @@ INSTALLED_APPS = (
     "django.contrib.flatpages",
     "django.contrib.redirects",
     "django.contrib.sitemaps",
-    'djangorestframework',
     'django_countries',
     "pagination",
     'reviews',
@@ -132,9 +141,11 @@ INSTALLED_APPS = (
     'lfs.supplier',
     'lfs.tagging',
     'lfs.tax',
+    "lfs.customer_tax",
     'lfs.utils',
     'lfs.voucher',
     'lfs_contact',
+    "lfs_order_numbers",
     'postal',
     'paypal.standard.ipn',
     'paypal.standard.pdt',
@@ -164,6 +175,7 @@ INTERNAL_IPS = (
     "127.0.0.1",
 )
 
+CACHE_MIDDLEWARE_KEY_PREFIX = "lfs"
 # CACHE_BACKEND = 'file:///'
 # CACHE_BACKEND = 'locmem:///'
 # CACHE_BACKEND = 'memcached://127.0.0.1:11211/'
@@ -181,6 +193,71 @@ LFS_PAYPAL_REDIRECT = True
 LFS_AFTER_ADD_TO_CART = "lfs_added_to_cart"
 LFS_RECENT_PRODUCTS_LIMIT = 5
 
+LFS_ORDER_NUMBER_GENERATOR = "lfs_order_numbers.models.OrderNumberGenerator"
+LFS_DOCS = "http://docs.getlfs.com/en/latest/"
+
+LFS_INVOICE_COMPANY_NAME_REQUIRED = False
+LFS_INVOICE_EMAIL_REQUIRED = True
+LFS_INVOICE_PHONE_REQUIRED = True
+
+LFS_SHIPPING_COMPANY_NAME_REQUIRED = False
+LFS_SHIPPING_EMAIL_REQUIRED = False
+LFS_SHIPPING_PHONE_REQUIRED = False
+
+LFS_PRICE_CALCULATORS = [
+    ['lfs.gross_price.GrossPriceCalculator', _(u'Price includes tax')],
+    ['lfs.net_price.NetPriceCalculator', _(u'Price excludes tax')],
+]
+
+LFS_SHIPPING_METHOD_PRICE_CALCULATORS = [
+    ["lfs.shipping.GrossShippingMethodPriceCalculator", _(u'Price includes tax')],
+    ["lfs.shipping.NetShippingMethodPriceCalculator", _(u'Price excludes tax')],
+]
+
+LFS_UNITS = [
+    u"l",
+    u"m",
+    u"qm",
+    u"cm",
+    u"lfm",
+    u"Package",
+    u"Piece",
+]
+
+LFS_PRICE_UNITS = LFS_BASE_PRICE_UNITS = LFS_PACKING_UNITS = LFS_UNITS
+
+LFS_LOG_FILE = DIRNAME + "/../lfs.log"
+LOGGING = {
+    "version": 1,
+    "formatters": {
+        "verbose": {
+            "format": "%(asctime)s %(levelname)s %(message)s",
+            "datefmt": "%a, %d %b %Y %H:%M:%S",
+        },
+    },
+    "handlers": {
+         "console":{
+            "level":"DEBUG",
+            "class":"logging.StreamHandler",
+            "formatter": "verbose",
+        },
+        'logfile': {
+            'level': 'DEBUG',
+            'class': 'logging.handlers.RotatingFileHandler',
+            'formatter': 'verbose',
+            'filename': LFS_LOG_FILE,
+            'mode': 'a',
+        },
+    },
+    "loggers": {
+        "default": {
+            "handlers": ["logfile", "console"],
+            "level": "DEBUG",
+            "propagate": False,
+        },
+    }
+}
+
 REVIEWS_SHOW_PREVIEW = False
 REVIEWS_IS_NAME_REQUIRED = False
 REVIEWS_IS_EMAIL_REQUIRED = False
